@@ -23,23 +23,16 @@
 Actions that perform cleaning
 """
 
-from __future__ import absolute_import
-
-from bleachbit import Command, FileUtilities, General, Special
-from bleachbit import _, expanduser, expandvars
+from bleachbit import Command, FileUtilities, General, Special, DeepScan
+from bleachbit import _, fs_scan_re_flags
 
 import glob
 import logging
 import os
 import re
-import types
-
-
 if 'posix' == os.name:
-    re_flags = 0
     from bleachbit import Unix
-else:
-    re_flags = re.IGNORECASE
+
 
 logger = logging.getLogger(__name__)
 
@@ -61,7 +54,7 @@ def expand_multi_var(s, variables):
         return (s,)
     var_keys_used = []
     ret = []
-    for var_key in variables.iterkeys():
+    for var_key in variables.keys():
         sub = '$$%s$$' % var_key
         if s.find(sub) > -1:
             var_keys_used.append(var_key)
@@ -70,14 +63,14 @@ def expand_multi_var(s, variables):
         return (s,)
     # filter the dictionary to the keys used
     vars_used = {key: value for key,
-                 value in variables.iteritems() if key in var_keys_used}
+                 value in variables.items() if key in var_keys_used}
     # create a product of combinations
     from itertools import product
     vars_product = (dict(zip(vars_used, x))
                     for x in product(*vars_used.values()))
     for var_set in vars_product:
         ms = s  # modified version of input string
-        for var_key, var_value in var_set.iteritems():
+        for var_key, var_value in var_set.items():
             sub = '$$%s$$' % var_key
             ms = ms.replace(sub, var_value)
         ret.append(ms)
@@ -104,10 +97,9 @@ class PluginMount(type):
             cls.plugins.append(cls)
 
 
-class ActionProvider:
+class ActionProvider(metaclass=PluginMount):
 
     """Abstract base class for performing individual cleaning actions"""
-    __metaclass__ = PluginMount
 
     def __init__(self, action_node, path_vars=None):
         """Create ActionProvider from CleanerML <action>"""
@@ -137,22 +129,22 @@ class FileActionProvider(ActionProvider):
         """Initialize file search"""
         ActionProvider.__init__(self, action_element, path_vars)
         self.regex = action_element.getAttribute('regex')
-        assert(isinstance(self.regex, (str, unicode, types.NoneType)))
+        assert(isinstance(self.regex, (str, type(None))))
         self.nregex = action_element.getAttribute('nregex')
-        assert(isinstance(self.nregex, (str, unicode, types.NoneType)))
+        assert(isinstance(self.nregex, (str, type(None))))
         self.wholeregex = action_element.getAttribute('wholeregex')
-        assert(isinstance(self.wholeregex, (str, unicode, types.NoneType)))
+        assert(isinstance(self.wholeregex, (str, type(None))))
         self.nwholeregex = action_element.getAttribute('nwholeregex')
-        assert(isinstance(self.nwholeregex, (str, unicode, types.NoneType)))
+        assert(isinstance(self.nwholeregex, (str, type(None))))
         self.search = action_element.getAttribute('search')
         self.object_type = action_element.getAttribute('type')
         self._set_paths(action_element.getAttribute('path'), path_vars)
-        self.ds = {}
+        self.ds = None
         if 'deep' == self.search:
-            self.ds['regex'] = self.regex
-            self.ds['nregex'] = self.nregex
-            self.ds['command'] = action_element.getAttribute('command')
-            self.ds['path'] = self.paths[0]
+            self.ds = (self.paths[0], DeepScan.Search(
+                command=action_element.getAttribute('command'),
+                regex=self.regex, nregex=self.nregex,
+                wholeregex=self.wholeregex, nwholeregex=self.nwholeregex))
             if not len(self.paths) == 1:
                 logger.warning(
                     # TRANSLATORS: Multi-value variables are explained in the online documentation.
@@ -169,7 +161,7 @@ class FileActionProvider(ActionProvider):
         self.paths = []
         # expand special $$foo$$ which may give multiple values
         for path2 in expand_multi_var(raw_path, path_vars):
-            path3 = expanduser(expandvars(path2))
+            path3 = os.path.expanduser(os.path.expandvars(path2))
             if os.name == 'nt' and path3:
                 # convert forward slash to backslash for compatibility with getsize()
                 # and for display.  Do not convert an empty path, or it will become
@@ -178,8 +170,8 @@ class FileActionProvider(ActionProvider):
             self.paths.append(path3)
 
     def get_deep_scan(self):
-        if 0 == len(self.ds):
-            raise StopIteration
+        if self.ds is None:
+            return
         yield self.ds
 
     def get_paths(self):
@@ -196,23 +188,23 @@ class FileActionProvider(ActionProvider):
         basename = os.path.basename
         object_type = self.object_type
         if self.regex:
-            regex_c_search = re.compile(self.regex, re_flags).search
+            regex_c_search = re.compile(self.regex, fs_scan_re_flags).search
         else:
             regex_c_search = None
 
         if self.nregex:
-            nregex_c_search = re.compile(self.nregex, re_flags).search
+            nregex_c_search = re.compile(self.nregex, fs_scan_re_flags).search
         else:
             nregex_c_search = None
 
         if self.wholeregex:
-            wholeregex_c_search = re.compile(self.wholeregex, re_flags).search
+            wholeregex_c_search = re.compile(self.wholeregex, fs_scan_re_flags).search
         else:
             wholeregex_c_search = None
 
         if self.nwholeregex:
             nwholeregex_c_search = re.compile(
-                self.nwholeregex, re_flags).search
+                self.nwholeregex, fs_scan_re_flags).search
         else:
             nwholeregex_c_search = None
 
@@ -278,7 +270,7 @@ class FileActionProvider(ActionProvider):
                 yield top
 
         if 'deep' == self.search:
-            raise StopIteration
+            return
         elif 'file' == self.search:
             func = get_file
         elif 'glob' == self.search:
@@ -513,6 +505,18 @@ class MozillaUrlHistory(FileActionProvider):
                                    _('Clean file'))
 
 
+class MozillaFavicons(FileActionProvider):
+
+    """Action to clean Mozilla (Firefox) URL history in places.sqlite"""
+    action_key = 'mozilla.favicons'
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Function(path,
+                                   Special.delete_mozilla_favicons,
+                                   _('Clean file'))
+
+
 class OfficeRegistryModifications(FileActionProvider):
 
     """Action to delete LibreOffice history"""
@@ -533,7 +537,7 @@ class Process(ActionProvider):
 
     def __init__(self, action_element, path_vars=None):
         ActionProvider.__init__(self, action_element, path_vars)
-        self.cmd = expandvars(action_element.getAttribute('cmd'))
+        self.cmd = os.path.expandvars(action_element.getAttribute('cmd'))
         # by default, wait
         self.wait = True
         wait = action_element.getAttribute('wait')
@@ -558,15 +562,7 @@ class Process(ActionProvider):
             else:
                 if not 0 == rc:
                     msg = 'Command: %s\nReturn code: %d\nStdout: %s\nStderr: %s\n'
-                    if isinstance(stdout, unicode):
-                        stdout = stdout.encode('utf-8')
-                    if isinstance(stderr, unicode):
-                        stderr = stderr.encode('utf-8')
-                    if isinstance(self.cmd, unicode):
-                        cmd = self.cmd.encode('utf-8')
-                    else:
-                        cmd = self.cmd
-                    logger.warning(msg, cmd, rc, stdout, stderr)
+                    logger.warning(msg, self.cmd, rc, stdout, stderr)
             return 0
         yield Command.Function(path=None, func=run_process, label=_("Run external command: %s") % self.cmd)
 
@@ -646,7 +642,7 @@ class YumCleanAll(ActionProvider):
     def get_commands(self):
         # Checking allows auto-hide to work for non-APT systems
         if not FileUtilities.exe_exists('yum'):
-            raise StopIteration
+            return
 
         yield Command.Function(
             None,
@@ -665,7 +661,7 @@ class DnfCleanAll(ActionProvider):
     def get_commands(self):
         # Checking allows auto-hide to work for non-APT systems
         if not FileUtilities.exe_exists('dnf'):
-            raise StopIteration
+            return
 
         yield Command.Function(
             None,
@@ -684,7 +680,7 @@ class DnfAutoremove(ActionProvider):
     def get_commands(self):
         # Checking allows auto-hide to work for non-APT systems
         if not FileUtilities.exe_exists('dnf'):
-            raise StopIteration
+            return
 
         yield Command.Function(
             None,
