@@ -259,7 +259,7 @@ def clean_json(path, target):
     targets = target.split('/')
 
     # read file to parser
-    with open(path, 'r') as f:
+    with open(path, 'r', encoding='utf-8') as f:
         js = json.load(f)
 
     # change file
@@ -287,7 +287,7 @@ def clean_json(path, target):
         if options.get('shred'):
             delete(path, True)
         # write file
-        with open(path, 'w') as f:
+        with open(path, 'w', encoding='utf-8') as f:
             json.dump(js, f)
 
 
@@ -422,7 +422,7 @@ def exe_exists(pathname):
         return exists_in_path(pathname)
 
 
-def execute_sqlite3(path, cmds):
+def execute_sqlite3(path, cmds, cmds_as_list=None):
     """Execute 'cmds' on SQLite database 'path'"""
     import sqlite3
     import contextlib
@@ -435,7 +435,10 @@ def execute_sqlite3(path, cmds):
         if options.get('shred'):
             cursor.execute('PRAGMA secure_delete=ON')
 
-        for cmd in cmds.split(';'):
+        if cmds_as_list is None:
+            cmds_as_list = cmds.split(';')
+
+        for cmd in cmds_as_list:
             try:
                 cursor.execute(cmd)
             except sqlite3.OperationalError as exc:
@@ -449,6 +452,7 @@ def execute_sqlite3(path, cmds):
             except sqlite3.DatabaseError as exc:
                 raise sqlite3.DatabaseError(
                     '%s: %s' % (exc, path))
+
         cursor.close()
         conn.commit()
 
@@ -863,7 +867,7 @@ def wipe_path(pathname, idle=False):
     def temporaryfile():
         # reference
         # http://en.wikipedia.org/wiki/Comparison_of_file_systems#Limits
-        maxlen = 245
+        maxlen = 185
         f = None
         while True:
             try:
@@ -875,11 +879,12 @@ def wipe_path(pathname, idle=False):
                     delete, f.name, allow_shred=False, ignore_missing=True)
                 break
             except OSError as e:
-                if e.errno in (errno.ENAMETOOLONG, errno.ENOSPC, errno.ENOENT):
+                if e.errno in (errno.ENAMETOOLONG, errno.ENOSPC, errno.ENOENT, errno.EINVAL):
                     # ext3 on Linux 3.5 returns ENOSPC if the full path is greater than 264.
                     # Shrinking the size helps.
 
                     # Microsoft Windows returns ENOENT "No such file or directory"
+                    # or EINVAL "Invalid argument"
                     # when the path is too long such as %TEMP% but not in C:\
                     if maxlen > 5:
                         maxlen -= 5
