@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/python3
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
@@ -31,7 +31,7 @@ from bleachbit.Cleaner import backends, register_cleaners
 import bleachbit
 from gi.repository import Gtk, Gdk, GObject, GLib, Gio
 
-
+import glob
 import logging
 import os
 import sys
@@ -116,7 +116,7 @@ class Bleachbit(Gtk.Application):
     _auto_exit = False
 
     def __init__(self, uac=True, shred_paths=None, auto_exit=False):
-        if uac and os.name == 'nt' and Windows.elevate_privileges():
+        if os.name == 'nt' and Windows.elevate_privileges(uac):
             # privileges escalated in other process
             sys.exit(0)
         Gtk.Application.__init__(
@@ -127,6 +127,10 @@ class Bleachbit(Gtk.Application):
             self._shred_paths = shred_paths
             return
         if os.name == 'nt':
+            # clean up nonce files https://github.com/bleachbit/bleachbit/issues/858
+            import atexit
+            atexit.register(Windows.cleanup_nonce)
+
             # BitDefender false positive.  BitDefender didn't mark BleachBit as infected or show
             # anything in its log, but sqlite would fail to import unless BitDefender was in "game mode."
             # https://www.bleachbit.org/forum/074-fails-errors
@@ -230,6 +234,10 @@ class Bleachbit(Gtk.Application):
             # in portable mode on Windows, the options directory includes
             # executables
             paths.append(bleachbit.options_file)
+            if os.path.isdir(bleachbit.personal_cleaners_dir):
+                paths.append(bleachbit.personal_cleaners_dir)
+            for f in glob.glob(os.path.join(bleachbit.options_dir, "*.bz2")):
+                paths.append(f)
         else:
             paths.append(bleachbit.options_dir)
 
@@ -239,14 +247,14 @@ class Bleachbit(Gtk.Application):
             # aborted
             return
 
-        # in portable mode, rebuild a minimal bleachbit.ini
-        bleachbit.Options.init_configuration()
-
         # Quit the application through the idle loop to allow the worker
         # to delete the files.  Use the lowest priority because the worker
         # uses the standard priority.  Otherwise, this will quit before
         # the files are deleted.
-        GLib.idle_add(self.quit, priority=GObject.PRIORITY_LOW)
+        #
+        # Rebuild a minimal bleachbit.ini when quitting
+        GLib.idle_add(self.quit, None, None, True,
+                      priority=GObject.PRIORITY_LOW)
 
     def cb_wipe_free_space(self, action, param):
         """callback to wipe free space in arbitrary folder"""
@@ -309,7 +317,9 @@ class Bleachbit(Gtk.Application):
         Gtk.Application.do_startup(self)
         self.build_app_menu()
 
-    def quit(self, _action=None, _param=None):
+    def quit(self, _action=None, _param=None, init_configuration=False):
+        if init_configuration:
+            bleachbit.Options.init_configuration()
         self._window.destroy()
 
     def get_diagnostics_dialog(self):
@@ -347,13 +357,13 @@ class Bleachbit(Gtk.Application):
             self._window = GUI(
                 application=self, title=APP_NAME, auto_exit=self._auto_exit)
         self._window.present()
+        if self._shred_paths:
+            GLib.idle_add(GUI.shred_paths, self._window, self._shred_paths)
+            self._auto_exit = True
         if self._auto_exit:
             GLib.idle_add(self.quit,
                           priority=GObject.PRIORITY_LOW)
             print('Success')
-        if self._shred_paths:
-            GLib.idle_add(GUI.shred_paths, self._window, self._shred_paths, False, True,
-                          priority=GObject.PRIORITY_LOW)
 
 
 class TreeInfoModel:
@@ -562,7 +572,7 @@ class GUI(Gtk.ApplicationWindow):
             self.cb_refresh_operations,
             self.set_windows10_theme)
 
-    def shred_paths(self, paths, shred_settings=False, quit_when_done=False):
+    def shred_paths(self, paths, shred_settings=False):
         """Shred file or folders
 
         When shredding_settings=True:
@@ -582,12 +592,7 @@ class GUI(Gtk.ApplicationWindow):
         if GuiBasic.delete_confirmation_dialog(self, mention_preview=False, shred_settings=shred_settings):
             # delete
             self.preview_or_run_operations(True, operations)
-            if shred_settings:
-                return True
-
-        if quit_when_done:
-            GLib.idle_add(self.close,
-                          priority=GObject.PRIORITY_LOW)
+            return True
 
         # user aborted
         return False
@@ -714,7 +719,7 @@ class GUI(Gtk.ApplicationWindow):
         else:
             self.start_time = time.time()
             worker = self.worker.run()
-            GLib.idle_add(worker.__next__, priority=GLib.PRIORITY_LOW)
+            GLib.idle_add(worker.__next__)
 
     def worker_done(self, worker, really_delete):
         """Callback for when Worker is done"""
