@@ -42,6 +42,7 @@ try:
 except AttributeError:
     Pattern = re._pattern_type
 
+
 class LocaleCleanerPath:
     """This represents a path with either a specific folder name or a folder name pattern.
     It also may contain several compiled regex patterns for localization items (folders or files)
@@ -658,8 +659,7 @@ def get_globs_size(paths):
     """Get the cumulative size (in bytes) of a list of globs"""
     total_size = 0
     for path in paths:
-        from glob import iglob
-        for p in iglob(path):
+        for p in glob.iglob(path):
             total_size += FileUtilities.getsize(p)
     return total_size
 
@@ -699,33 +699,30 @@ units = {"B": 1, "k": 10**3, "M": 10**6, "G": 10**9}
 
 
 def parseSize(size):
+    """Parse the size returned by dnf"""
     number, unit = [string.strip() for string in size.split()]
     return int(float(number)*units[unit])
 
 
 def dnf_autoremove():
-    """Run 'dnf autoremove' and return size in bytes recovered"""
+    """Run 'dnf autoremove' and return size in bytes recovered."""
     if os.path.exists('/var/run/dnf.pid'):
         msg = _(
             "%s cannot be cleaned because it is currently running.  Close it, and try again.") % "Dnf"
         raise RuntimeError(msg)
     cmd = ['dnf', '-y', 'autoremove']
-    process = subprocess.Popen(
-        cmd, stderr=subprocess.STDOUT, stdout=subprocess.PIPE)
+    (rc, stdout, stderr) = General.run_external(cmd)
     freed_bytes = 0
-    while True:
-        line = process.stdout.readline().replace("\n", "")
-        if 'Error: This command has to be run under the root user.' == line:
-            raise RuntimeError('dnf autoremove >> requires root permissions')
-        if 'Nothing to do.' == line:
-            break
-        cregex = re.compile("Freed space: ([\d.]+[\s]+[BkMG])")
-        match = cregex.search(line)
-        if match:
-            freed_bytes = parseSize(match.group(1))
-            break
-        if "" == line and process.poll() != None:
-            break
+    allout = stdout + stderr
+    if 'Error: This command has to be run under the root user.' in allout:
+        raise RuntimeError('dnf autoremove >> requires root permissions')
+    if rc > 0:
+        raise RuntimeError('dnf raised error %s: %s' % (rc, stderr))
+
+    cregex = re.compile("Freed space: ([\d.]+[\s]+[BkMG])")
+    match = cregex.search(allout)
+    if match:
+        freed_bytes = parseSize(match.group(1))
     logger.debug(
         'dnf_autoremove >> total freed bytes: %s', freed_bytes)
     return freed_bytes
