@@ -43,7 +43,6 @@ from bleachbit import Command, FileUtilities, General
 import glob
 import logging
 import os
-import re
 import sys
 
 from decimal import Decimal
@@ -55,7 +54,7 @@ if 'win32' == sys.platform:
     import win32con
     import win32file
     import win32gui
-    import win32process
+    import win32security
 
     from ctypes import windll, c_ulong, c_buffer, byref, sizeof
     from win32com.shell import shell, shellcon
@@ -122,6 +121,13 @@ def browse_folder(_, title):
     return fullpath
 
 
+def cleanup_nonce():
+    """On exit, clean up GTK junk files"""
+    for fn in glob.glob(os.path.expandvars('%TEMP%\gdbus-nonce-file-*')):
+        logger.debug('cleaning GTK nonce file: %s', fn)
+        FileUtilities.delete(fn)
+
+
 def csidl_to_environ(varname, csidl):
     """Define an environment variable from a CSIDL for use in CleanerML and Winapp2.ini"""
     try:
@@ -253,13 +259,23 @@ def detect_registry_key(parent_key):
     return True
 
 
-def elevate_privileges():
+def elevate_privileges(uac):
     """On Windows Vista and later, try to get administrator
     privileges.  If successful, return True (so original process
     can exit).  If failed or not applicable, return False."""
 
     if shell.IsUserAnAdmin():
         logger.debug('already an admin (UAC not required)')
+        htoken = win32security.OpenProcessToken(
+            win32api.GetCurrentProcess(), win32security.TOKEN_ADJUST_PRIVILEGES | win32security.TOKEN_QUERY)
+        newPrivileges = [
+            (win32security.LookupPrivilegeValue(None, "SeBackupPrivilege"), win32security.SE_PRIVILEGE_ENABLED),
+            (win32security.LookupPrivilegeValue(None, "SeRestorePrivilege"), win32security.SE_PRIVILEGE_ENABLED),
+        ]
+        win32security.AdjustTokenPrivileges(htoken, 0, newPrivileges)
+        win32file.CloseHandle(htoken)
+        return False
+    elif not uac:
         return False
 
     if hasattr(sys, 'frozen'):
